<template>
    <div class="app-container">
        <div class="filter-container">
            <div style="display: block;">
                <div class="basic_search" style="padding-top: 10px">
                    <span>按企业名称：</span>
                    <el-input filterable clearable v-model="listQuery.filter.enterprisename" style="width:200px">
                    </el-input>
                </div>
                <div class="basic_search" style="margin-right: 10px">
                    <el-button style="margin-left: 10px;" type="primary" @click="add()">新增</el-button>
                    <el-button style="margin-left: 10px;" type="primary" icon="el-icon-search" @click="search('查询','')">查询</el-button>
                </div>
            </div>
        </div>
        <div class="table_content">
            <el-table
                v-loading="listLoading"
                :key="tableKey"
                :data="blackList"
                border
                fit
                highlight-current-row
                style="width: 100%;"
            >
                <el-table-column label="序号" type="index" align="center" width="60"/>
                <el-table-column label="企业名称" prop="enterprisename" align="center">
                </el-table-column>
                <el-table-column label="企业编号" prop="enterprisenumber" align="center">
                </el-table-column>
                <el-table-column label="创建人" prop="createby" align="center">
                </el-table-column>
                <el-table-column label="创建时间" prop="createtime" align="center">
                </el-table-column>
                <el-table-column label="操作" align="center">
                    <template slot-scope="scope">
                        <el-button type="text" @click="deleteById(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br>
            <el-pagination
                v-show="recordTotal>0"
                :current-page="currentPage"
                :page-sizes="[10, 20, 30, 50]"
                :page-size="pageSize"
                :total="recordTotal"
                layout="total, sizes, prev, pager, next, jumper"
                background
                style="float:right;"
                @size-change="handleSizeChange"
                @current-change="handleCurrentChange"
            />
            <br>
        </div>
        <el-dialog
            width="30%"
            :visible.sync="dialogVisible"
            :close-on-click-modal="false"
            :close-on-press-escape="false">
            <el-form :model="blackQuery" ref="ruleForm" label-width="200px">
                <el-row>
                    <el-col :span="20">
                        <el-form-item label="企业名称" prop="enterprisename" >
                            <el-input v-model="blackQuery.enterprisename">
                            </el-input>
                        </el-form-item>
                    </el-col>
                </el-row>
            </el-form>
            <div align="center">
                <el-button @click="dialogVisible = false">取消</el-button>
                <el-button type="primary" @click="submit()">确定</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {addBlackList, deleteBlackList, getBlackList} from "../../../api/blackList";
import {computePageCount} from "../../../utils";
import {mapGetters} from "vuex";
import {getEnterprise, refuseSaleJudge} from "../../../api/saleJudge";

export default {
    name: "blackList",
    data(){
        return{
            pageSize: 10,
            recordTotal: 0,
            currentPage: 1,
            pageTotal: 0,
            tableKey: 0,
            listLoading:false,
            blackList:[],
            dialogVisible:false,
            enterpriseList:[],
            blackQuery:{
                enterprisename:'',
            },
            listQuery:{
                filter:{
                    enterprisename:''
                },
                pageIndex:1,
                pageSize:10,
            },
        }
    },
    computed: {
        ...mapGetters([
            'userType',
            'username'
        ])
    },
    created() {
        this.getBlackDataList()
        this.getEnterpriseList()
    },
    methods:{
        async getBlackDataList(){
            this.listLoading = true
            let res = await getBlackList(this.listQuery)
            if(res.data.code === "200"){
                this.recordTotal = res.data.result.total
                this.pageSize = res.data.result.size
                this.pageTotal = computePageCount(res.data.result.totalCount, res.data.result.pageSize)
                this.currentPage = res.data.result.current
                this.blackList = res.data.result.records
            }else{
                this.$message({
                    type:'warning',
                    message:res.data.message
                })
            }
            this.listLoading = false
        },
        async getEnterpriseList(){
            let type = 0
            let res= await getEnterprise(type)
            if(res.data.code === '200'){
                this.enterpriseList = res.data.result
            }
        },
        search(){
            this.getBlackDataList()
        },
        add(){
            this.dialogVisible = true
            this.blackQuery = {
                enterprisename:'',
                enterprisenumber:''
            }
        },
        submit(val){
            this.$confirm('将该企业加入黑名单，是否继续','提示',{
                confirmButtonText:'确定',
                cancelButtonText:'取消',
                type:'warning',
            }).then(()=> {
                addBlackList(this.blackQuery).then( (res)=>{
                    if(res.data.code === "200"){
                        this.dialogVisible = false
                        this.getBlackDataList()
                        this.$notify({
                            title:'成功',
                            message:'加入黑名单成功',
                            type:'success',
                            duration:2000,
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                })
            })
        },
        handleSizeChange: function(val) {
            this.listQuery.pageSize = val
            this.getBlackDataList()
        },
        handleCurrentChange: function(val) {
            this.listQuery.pageIndex = val
            this.getBlackDataList()
        },
        deleteById(val){
            this.$confirm('删除该黑名单，是否继续','提示',{
                confirmButtonText:'确定',
                cancelButtonText:'取消',
                type:'warning',
            }).then(()=> {
                deleteBlackList(val.id).then( (res)=>{
                    if(res.data.code === "200"){
                        this.dialogVisible = false
                        this.getBlackDataList()
                        this.$notify({
                            title:'成功',
                            message:'删除成功',
                            type:'success',
                            duration:2000,
                        })
                    }else{
                        this.$message({
                            type:'warning',
                            message:res.data.message
                        })
                    }
                })
            })
        },
    },
}
</script>

<style scoped>
.basic_search{
    display:inline-block;
}

</style>
